@@ -1,5 +1,5 @@
 *
-*    $Id: mvt.f 3864 2008-02-10 16:43:04Z hothorn $
+*    $Id: mvt.f 195 2009-03-25 11:39:37Z thothorn $
 *
       SUBROUTINE MVTDST( N, NU, LOWER, UPPER, INFIN, CORREL, DELTA, 
      &                   MAXPTS, ABSEPS, RELEPS, ERROR, VALUE, INFORM )       
@@ -19,7 +19,7 @@
 *	Original source available from
 *	http://www.math.wsu.edu/faculty/genz/software/fort77/mvtdstpack.f
 *
-*	This is version 7/7 with better support for 100 < dimension < 1000
+*	This is version 7/10 with better support for 100 < dimension < 1000
 *
 *  Parameters
 *
@@ -62,6 +62,7 @@
      &                 ABSEPS, ERROR, VALUE, E(1), V(1)
       COMMON /PTBLCK/IVLS
       IVLS = 0
+
       IF ( N .GT. 1000 .OR. N .LT. 1 ) THEN
          VALUE = 0
          ERROR = 1
@@ -79,6 +80,7 @@
             VALUE = V(1)
          ENDIF
       ENDIF
+      
       END
 *
       SUBROUTINE MVSUBR( N, W, NF, F )
@@ -130,6 +132,10 @@
 *
          IF ( ND .EQ. 0 ) THEN
             ER = 0
+*  Code added to fix ND = 0 bug, 24/03/2009 ->
+            VL = 1
+*  <- Code added to fix ND = 0 bug, 24/03/2009
+
          ELSE IF ( ND.EQ.1 .AND. ( NU.LT.1 .OR. ABS(DL(1)).EQ.0 ) ) THEN
 *     
 *           1-d case for normal or central t
@@ -255,7 +261,7 @@
       INTEGER I, J, K, L, M, II, IJ, IL, JL, JMIN
       DOUBLE PRECISION SUMSQ, AJ, BJ, SUM, EPS, EPSI, D, E
       DOUBLE PRECISION CVDIAG, AMIN, BMIN, DEMIN, MVTDNS
-      PARAMETER ( EPS = 1D-6 )
+      PARAMETER ( EPS = 1D-10 )
       INFORM = 0
       IJ = 0
       II = 0
@@ -293,8 +299,8 @@
                   ENDIF
                END DO
             ENDIF
+ 10         CONTINUE
          END DO
- 10   CONTINUE
 *
 *     Sort remaining limits and determine Cholesky factor.
 *
@@ -309,7 +315,7 @@
             JMIN = I
             CVDIAG = 0
             IJ = II
-            EPSI = EPS*I*I
+            EPSI = EPS*I
             IF ( .NOT. PIVOT ) JL = I
             DO J = I, JL
                IF ( COV(IJ+J) .GT. EPSI ) THEN
